@@ -37,7 +37,7 @@ class SelectorTest extends TestCase
         return preg_replace($patterns, $replacements, $selector);
     }
 
-    public function selectorMatchesProvider(): array
+    public static function selectorMatchesProvider(): array
     {
         // Elements expected to matched by each selector are marked with the
         // attribute `data-match`. The optional third parameter defines whether
@@ -742,12 +742,19 @@ class SelectorTest extends TestCase
                 '[title*=""]',
                 '<body><div title="multiple tokens"></div><div title=""></div></body>'
             ],
+
+            // escaped selector characteres
+            "escaped classname characters" => [
+                '.w-\[var\(--sidebar-width\)\]',
+                '<body><div class="w-\[var\(--sidebar-width\)\]"></div></body>'
+            ]
         ];
     }
 
     /**
      * @dataProvider selectorMatchesProvider
      */
+    #[\PHPUnit\Framework\Attributes\DataProvider('selectorMatchesProvider')]
     public function testSelectorMatches(
         string $selector,
         string $body,
@@ -788,12 +795,9 @@ class SelectorTest extends TestCase
         }
     }
 
-    public function selectorInvalidProvider(): array
+    public static function selectorInvalidProvider(): array
     {
         return [
-            // Valid but unsupported selector syntax
-            [".w-\[var\(--sidebar-width\)\]"],
-
             // Invalid selectors
             [":unknown"],
             ["p:unknown"],
@@ -806,6 +810,7 @@ class SelectorTest extends TestCase
     /**
      * @dataProvider selectorInvalidProvider
      */
+    #[\PHPUnit\Framework\Attributes\DataProvider('selectorInvalidProvider')]
     public function testSelectorInvalid(string $selector): void
     {
         $sheet = $this->stylesheet();
